@@ -2,14 +2,15 @@
 def fix_dependencies():
     import __main__
     __main__.__requires__ = ['jetto_tools>=1.8.8']
+    __main__.__requires__ = ['jinja2>=3.0.0']
     import pkg_resources  # noqa
 
 
 fix_dependencies()
 
-__author__ = 'Carbon Collective'
+__author__ = 'Stef Smeets'
 __email__ = 's.smeets@esciencecenter.nl'
-__version__ = '1.3.0'
+__version__ = '1.5.0'
 
 import logging  # noqa
 import warnings  # noqa
