@@ -4,7 +4,7 @@ Functions:
 
 - [rebase_on_grid][duqtools.api.rebase_on_grid]
 - [rebase_on_time][duqtools.api.rebase_on_time]
-- [standardize_datasets][duqtools.api.standardize_datasets]
+- [standardize_grid_and_time][duqtools.api.standardize_grid_and_time]
 
 Data classes:
 
@@ -19,8 +19,13 @@ Plotting:
 """
 
 from ._plot_utils import alt_errorband_chart, alt_line_chart
-from .ids import (IDSMapping, ImasHandle, rebase_on_grid, rebase_on_time,
-                  standardize_grid_and_time)
+from .ids import (
+    IDSMapping,
+    ImasHandle,
+    rebase_on_grid,
+    rebase_on_time,
+    standardize_grid_and_time,
+)
 from .schema import IDSVariableModel as Variable
 
 __all__ = [
