@@ -1,13 +1,14 @@
 import logging
 import shutil
+import warnings
 from pathlib import Path
-from typing import Any, List, Sequence
+from typing import Any, Sequence
 
 import pandas as pd
 
 from .apply_model import apply_model
 from .cleanup import remove_run
-from .config import cfg
+from .config import Config, cfg
 from .ids import ImasHandle
 from .matrix_samplers import get_matrix_sampler
 from .models import Locations
@@ -38,7 +39,10 @@ class CreateManager:
         self.system = get_system()
         self.runs_dir = self.system.get_runs_dir()
         self.source = self._get_source_handle()
-        self.runs_yaml = Locations().runs_yaml
+
+        locations = Locations()
+        self.runs_yaml = locations.runs_yaml
+        self.data_csv = locations.data_csv
 
     def _get_source_handle(self) -> ImasHandle:
         if not self.options.template_data:
@@ -50,7 +54,7 @@ class CreateManager:
 
         return source
 
-    def generate_ops_list(self) -> List[Any]:
+    def generate_ops_list(self) -> list[Any]:
         """Generate set of operations for a run."""
         dimensions = self.options.dimensions
         matrix_sampler = get_matrix_sampler(self.options.sampler.method)
@@ -59,27 +63,33 @@ class CreateManager:
 
         return ops_list
 
-    def make_run_models(self, ops_list: Sequence[Any]) -> List[Run]:
+    def make_run_models(self, ops_list: Sequence[Any]) -> list[Run]:
         """Take list of operations and create run models."""
         run_models = []
 
         for i, operations in enumerate(ops_list):
             dirname = self.runs_dir / f'{RUN_PREFIX}{i:04d}'
 
-            data_in = ImasHandle(user=self.options.data.user,
-                                 db=self.options.data.imasdb,
-                                 shot=self.source.shot,
-                                 run=self.options.data.run_in_start_at + i)
-            data_out = ImasHandle(user=self.options.data.user,
-                                  db=self.options.data.imasdb,
-                                  shot=self.source.shot,
-                                  run=self.options.data.run_out_start_at + i)
+            data_in = self.system.get_data_in_handle(
+                dirname=dirname,
+                seq_number=i,
+                source=self.source,
+                options=self.options.data,
+            )
+
+            data_out = self.system.get_data_out_handle(
+                dirname=dirname,
+                seq_number=i,
+                source=self.source,
+                options=self.options.data,
+            )
 
             model = Run(dirname=dirname.resolve(),
                         shortname=dirname.name,
                         data_in=data_in,
                         data_out=data_out,
                         operations=operations)
+
             run_models.append(model)
 
         return run_models
@@ -123,47 +133,59 @@ class CreateManager:
 
     def warn_no_create_runs(self):
         """Add warning to op queue if runs will not be created."""
-        op_queue.add_no_op(description='Not creating runs',
-                           extra_description='some targets already exist, '
-                           'use --force to override')
+        op_queue.warning(description='Warning',
+                         extra_description='Some targets already exist, '
+                         'use --force to override')
 
     @add_to_op_queue('Setting inital condition of', '{data_in}', quiet=True)
     def apply_operations(self, data_in: ImasHandle, run_dir: Path,
-                         operations: List[Any]):
+                         operations: list[Any]):
         for model in operations:
             apply_model(model, run_dir=run_dir, ids_mapping=data_in)
 
     @add_to_op_queue('Writing runs', '{self.runs_yaml}', quiet=True)
     def write_runs_file(self, runs: Sequence[Run]) -> None:
         runs = Runs.parse_obj(runs)
-        with open(self.runs_yaml, 'w') as f:
-            runs.yaml(stream=f)
 
-        # Only if it is a different directory
-        if Path.cwd().resolve() != self.runs_dir.resolve():
-            with open(self.runs_dir / 'runs.yaml', 'w') as f:
+        with warnings.catch_warnings():
+            warnings.simplefilter('ignore')
+            with open(self.runs_yaml, 'w') as f:
                 runs.yaml(stream=f)
 
+            # Only if it is a different directory
+            if self._is_runs_dir_different_from_config_dir():
+                with open(self.runs_dir / 'runs.yaml', 'w') as f:
+                    runs.yaml(stream=f)
+
     @add_to_op_queue('Writing csv', quiet=True)
-    def write_runs_csv(self, runs: Sequence[Run], fname: str = 'data.csv'):
-        run_map = {run.dirname: run.data_out.dict() for run in runs}
+    def write_runs_csv(self, runs: Sequence[Run], cfg: Config):
+        fname = self.data_csv
+
+        prefix = f'{cfg.tag}.' if cfg.tag else ''
+
+        run_map = {
+            f'{prefix}{run.shortname}': run.data_out.dict()
+            for run in runs
+        }
         df = pd.DataFrame.from_dict(run_map, orient='index')
         df.to_csv(fname)
 
-        # Only if it is a different directory
-        if Path.cwd().resolve() != self.runs_dir.resolve():
+        if self._is_runs_dir_different_from_config_dir():
             df.to_csv(self.runs_dir / fname)
 
     @add_to_op_queue('Storing duqtools.yaml inside runs_dir', quiet=True)
     def copy_config(self, config):
-        # Only if it is a different directory
-        if Path.cwd().resolve() != self.runs_dir.resolve():
+        if self._is_runs_dir_different_from_config_dir():
             shutil.copyfile(Path.cwd() / config,
                             self.runs_dir / 'duqtools.yaml')
 
+    def _is_runs_dir_different_from_config_dir(self) -> bool:
+        """Return True if the runs dir is different from the duqtools config
+        dir."""
+        return Path.cwd().resolve() != self.runs_dir.resolve()
+
     def create_run(self, model: Run, *, force: bool = False):
         """Take a run model and create it."""
-
         op_queue.add(action=model.dirname.mkdir,
                      kwargs={
                          'parents': True,
@@ -178,7 +200,7 @@ class CreateManager:
 
         self.apply_operations(model.data_in, model.dirname, model.operations)
 
-        self.system.write_batchfile(model.dirname)
+        self.system.write_batchfile(model.dirname, cfg)
 
         self.system.update_imas_locations(run=model.dirname,
                                           inp=model.data_in,
@@ -220,7 +242,7 @@ def create(*, force, config, **kwargs):
         create_mgr.create_run(model, force=force)
 
     create_mgr.write_runs_file(runs)
-    create_mgr.write_runs_csv(runs)
+    create_mgr.write_runs_csv(runs, cfg)
     create_mgr.copy_config(config)
 
 
