@@ -4,9 +4,15 @@ from ._handle import ImasHandle
 from ._imas import imas_mocked
 from ._mapping import IDSMapping
 from ._merge import merge_data
-from ._rebase import (rebase_all_coords, rebase_on_grid, rebase_on_time,
-                      squash_placeholders, standardize_grid,
-                      standardize_grid_and_time, standardize_time)
+from ._rebase import (
+    rebase_all_coords,
+    rebase_on_grid,
+    rebase_on_time,
+    squash_placeholders,
+    standardize_grid,
+    standardize_grid_and_time,
+    standardize_time,
+)
 
 logger = logging.getLogger(__name__)
 
