@@ -1,22 +1,25 @@
 import logging
+import os
 import shutil
 import stat
 import subprocess as sp
 import sys
+from collections.abc import Sequence
 from pathlib import Path
-from typing import Any, List, Optional, Sequence
+from typing import Any, List, Optional
 
-from jetto_tools import config
+from jetto_tools import config, jset, lookup, namelist, template
 from jetto_tools import job as jetto_job
-from jetto_tools import jset, lookup, namelist, template
+from jetto_tools.template import _EXTRA_FILE_REGEXES
 
-from ..config import cfg
+from ..config import Config, cfg
 from ..ids import ImasHandle
 from ..models import AbstractSystem, Job, Locations
 from ..operations import add_to_op_queue
 from ..schema import JettoVar
+from ._batchfile import write_array_batchfile as _write_array_batchfile
+from ._batchfile import write_batchfile as _write_batchfile
 from ._jettovar_to_json import jettovar_to_json
-from ._llcmd import write_batchfile as jetto_write_batchfile
 
 if sys.version_info < (3, 10):
     from importlib_resources import files
@@ -29,7 +32,12 @@ lookup_file = files('duqtools.data') / 'jetto_tools_lookup.json'
 jetto_lookup = lookup.from_file(lookup_file)
 
 
-class JettoSystem(AbstractSystem):
+class BaseJettoSystem(AbstractSystem):
+    """System that can be used to create runs for jetto.
+
+    This system can submit to various backends like docker, prominence
+    and the gateway.
+    """
 
     @staticmethod
     def get_runs_dir() -> Path:
@@ -52,30 +60,37 @@ class JettoSystem(AbstractSystem):
 
     @staticmethod
     @add_to_op_queue('Writing new batchfile', '{run_dir.name}', quiet=True)
-    def write_batchfile(run_dir: Path):
-
+    def write_batchfile(run_dir: Path, cfg: Config):
         jetto_jset = jset.read(run_dir / 'jetto.jset')
-
-        jetto_write_batchfile(run_dir, jetto_jset)
+        _write_batchfile(run_dir, jetto_jset, tag=cfg.tag)
 
     @staticmethod
     def submit_job(job: Job):
-        if cfg.submit.submit_system == 'slurm':
-            JettoSystem.submit_slurm(job)
-        elif cfg.submit.submit_system == 'prominence':
-            JettoSystem.submit_prominence(job)
+        # Make sure we get a new correct status
+        if (job.dir / 'jetto.status').exists():
+            os.remove(job.dir / 'jetto.status')
+
+        submit_system = job.cfg.submit.submit_system
+
+        if submit_system == 'slurm':
+            submit = JettoSystem.submit_slurm
+        elif submit_system == 'docker':
+            submit = JettoSystem.submit_docker
+        elif submit_system == 'prominence':
+            submit = JettoSystem.submit_prominence
         else:
-            raise NotImplementedError(
-                'submission type {cfg.submit.submit_system}'
-                ' not implemented')
+            raise NotImplementedError(f'submission type {submit_system}'
+                                      ' not implemented')
+
+        submit(job)
 
     @staticmethod
     def submit_slurm(job: Job):
         if not job.has_submit_script:
             raise FileNotFoundError(job.submit_script)
 
-        submit_cmd = cfg.submit.submit_command.split()
-        cmd: List[Any] = [*submit_cmd, str(job.submit_script)]
+        submit_cmd = job.cfg.submit.submit_command.split()
+        cmd: list[Any] = [*submit_cmd, str(job.submit_script)]
 
         logger.info(f'submitting script via slurm {cmd}')
 
@@ -85,67 +100,73 @@ class JettoSystem(AbstractSystem):
             f.write(ret.stdout)
 
     @staticmethod
-    def submit_prominence(job: Job):
+    def submit_docker(job: Job):
+        jetto_template = template.from_directory(job.dir)
+        jetto_config = config.RunConfig(jetto_template)
+        jetto_manager = jetto_job.JobManager()
+        extra_volumes = {
+            job.dir.parent / 'imasdb': {
+                'bind': '/opt/imas/shared/imasdb',
+                'mode': 'rw'
+            },
+        }
 
+        os.environ['RUNS_HOME'] = os.getcwd()
+        os.environ['JINTRAC_IMAS_BACKEND'] = 'MDSPLUS'
+        container = jetto_manager.submit_job_to_docker(
+            jetto_config,
+            job.dir,
+            image=job.cfg.submit.docker_image,
+            extra_volumes=extra_volumes)
+        job.lockfile.touch()
+        with open(job.lockfile, 'w') as f:
+            f.write(container.name)
+
+    @staticmethod
+    def submit_prominence(job: Job):
         jetto_template = template.from_directory(job.dir)
         jetto_config = config.RunConfig(jetto_template)
         jetto_manager = jetto_job.JobManager()
 
+        os.environ['RUNS_HOME'] = os.getcwd()
         _ = jetto_manager.submit_job_to_prominence(jetto_config, job.dir)
 
     @staticmethod
-    def submit_array(jobs: Sequence[Job]):
-        if cfg.submit.submit_system == 'slurm':
-            JettoSystem.submit_array_slurm(jobs)
+    def submit_array(jobs: Sequence[Job], max_jobs: int):
+        if jobs[0].cfg.submit.submit_system == 'slurm':
+            JettoSystem.submit_array_slurm(jobs, max_jobs)
         else:
             raise NotImplementedError(
-                'array submission type {cfg.submit.submit_system}'
+                'array submission type {jobs[0].cfg.submit.submit_system}'
                 ' not implemented')
 
     @staticmethod
     @add_to_op_queue('Submit single array job', 'duqtools_slurm_array.sh')
-    def submit_array_slurm(jobs: Sequence[Job]):
+    def submit_array_slurm(jobs: Sequence[Job], max_jobs: int):
         for job in jobs:
             job.lockfile.touch()
 
-        # Get the first jobs submission script as a template
-        template = []
-        for line in open(jobs[0].submit_script).readlines():
-            if line.startswith('#SBATCH') or line.startswith('#!'):
-                template.append(line)
-        # Append our own options, later options have precedence
-        template.append('#SBATCH -o duqtools_slurm_array.out\n')
-        template.append('#SBATCH -e duqtools_slurm_array.err\n')
-        template.append('#SBATCH --array=0-' + str(len(jobs) - 1) + '\n')
-        template.append('#SBATCH -J duqtools_array\n')
-
-        scripts = [str(job.submit_script) for job in jobs]
-        script_str = 'scripts=(' + ' '.join(scripts) + ')\n'
-        template.append(script_str)
-
-        template.append('echo executing ${scripts[$SLURM_ARRAY_TASK_ID]}\n')
-        template.append('${scripts[$SLURM_ARRAY_TASK_ID]} || true\n')
-
         logger.info('writing duqtools_slurm_array.sh file')
-        with open('duqtools_slurm_array.sh', 'w') as f:
-            f.write(''.join(template))
+        _write_array_batchfile(jobs, max_jobs)
 
-        submit_cmd = cfg.submit.submit_command.split()
-        cmd: List[Any] = [*submit_cmd, 'duqtools_slurm_array.sh']
+        submit_cmd = jobs[0].cfg.submit.submit_command.split()
+        cmd: list[Any] = [*submit_cmd, 'duqtools_slurm_array.sh']
 
         logger.info(f'Submitting script via: {cmd}')
 
         ret = sp.run(cmd, check=True, capture_output=True)
         logger.info('submission returned: ' + str(ret.stdout))
-        with open(job.lockfile, 'wb') as f:
-            f.write(ret.stdout)
+
+        for job in jobs:
+            with open(job.lockfile, 'wb') as f:
+                f.write(ret.stdout)
 
     @staticmethod
     def _apply_patches_to_template(jetto_template: template.Template):
         """Apply settings that are necessary for duqtools to function."""
         # Force output of IDS data
         # https://github.com/duqtools/duqtools/issues/343
-        jetto_template.jset._settings['JobProcessingPanel.selIdsRunid'] = False
+        jetto_template.jset._settings['JobProcessingPanel.selIdsRunid'] = True
 
     @staticmethod
     @add_to_op_queue('Copying template to', '{target_drc}', quiet=True)
@@ -157,9 +178,19 @@ class JettoSystem(AbstractSystem):
         if (source_drc / 'jetto.sin').exists():
             jetto_sanco = namelist.read(source_drc / 'jetto.sin')
 
-        jetto_extra = []
-        if (source_drc / 'jetto.ex').exists():
-            jetto_extra = [str(source_drc / 'jetto.ex')]
+        all_files = os.listdir(source_drc)
+
+        jetto_extra: List[str] = []
+        for regex in _EXTRA_FILE_REGEXES:
+            jetto_extra.extend(filter(regex.match, all_files))
+
+        if 'jetto.restart' in jetto_extra or 'jetto.srestart' in jetto_extra:
+            raise OSError(
+                'Template contains `jetto.restart` and/or `jetto.srestart` files. '
+                'Please remove these before running duqtools again. '
+                'More info: https://github.com/duqtools/duqtools/issues/498')
+
+        jetto_extra = [str(source_drc / file) for file in jetto_extra]
 
         jetto_template = template.Template(jset=jetto_jset,
                                            namelist=jetto_namelist,
@@ -197,7 +228,6 @@ class JettoSystem(AbstractSystem):
     @staticmethod
     @add_to_op_queue('Updating imas locations of', '{run}', quiet=True)
     def update_imas_locations(run: Path, inp: ImasHandle, out: ImasHandle):
-
         jetto_template = template.from_directory(run)
         jetto_config = config.RunConfig(jetto_template)
 
@@ -233,3 +263,108 @@ class JettoSystem(AbstractSystem):
             jetto_config[key] = value
 
         jetto_config.export(run)  # Just overwrite the poor files
+
+
+class JettoSystemV210921(BaseJettoSystem):
+    """System that can be used to create runs for jetto.
+
+    The backend that is  assumed is jetto-v210921.
+
+    This system can submit to various backends like docker, prominence
+    and the gateway.
+
+    ```yaml title="duqtools.yaml"
+    system: jetto-v210921
+    submit:
+      submit_system: prominence
+    ```
+    """
+
+    @staticmethod
+    def get_data_in_handle(
+        *,
+        dirname: Path,
+        source: ImasHandle,
+        seq_number: int,
+        options,
+    ):
+        """Get handle for data input."""
+        return ImasHandle(
+            user=options.user,
+            db=options.imasdb,
+            shot=source.shot,
+            run=options.run_in_start_at + seq_number,
+        )
+
+    @staticmethod
+    def get_data_out_handle(
+        *,
+        dirname: Path,
+        source: ImasHandle,
+        seq_number: int,
+        options,
+    ):
+        """Get handle for data output."""
+        return ImasHandle(
+            user=options.user,
+            db=options.imasdb,
+            shot=source.shot,
+            run=options.run_out_start_at + seq_number,
+        )
+
+
+class JettoSystemV220922(BaseJettoSystem):
+    """System that can be used to create runs for jetto.
+
+    The backend that is  assumed is jetto-v220922. The most important
+    difference with v210921 is that the IMAS data is handled locally
+    instead of via a public `imasdb`
+
+    This system can submit to various backends like docker, prominence
+    and the gateway.
+
+    ```yaml title="duqtools.yaml"
+    system: jetto-v220922
+    submit:
+      submit_system: docker
+    ```
+    """
+
+    @staticmethod
+    def get_data_in_handle(
+        *,
+        dirname: Path,
+        source: ImasHandle,
+        seq_number: int,
+        options,
+    ):
+        """Get handle for data input."""
+        return ImasHandle(
+            user=str((dirname / 'imasdb').resolve()),
+            db=source.db,
+            shot=source.shot,
+            run=1,
+        )
+
+    @staticmethod
+    def get_data_out_handle(
+        *,
+        dirname: Path,
+        source: ImasHandle,
+        seq_number: int,
+        options,
+    ):
+        relative_location: Optional[str] = str(
+            os.path.relpath((dirname / 'imasdb').resolve()))
+        if relative_location:
+            if relative_location.startswith('..'):
+                relative_location = None
+        """Get handle for data output."""
+        return ImasHandle(user=str((dirname / 'imasdb').resolve()),
+                          db=source.db,
+                          shot=source.shot,
+                          run=2,
+                          relative_location=relative_location)
+
+
+JettoSystem = JettoSystemV220922
