@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from pathlib import Path
-from typing import List, Union
+from typing import Union
 
 from pydantic import Field, root_validator
 
@@ -15,8 +15,8 @@ class Run(BaseModel):
     shortname: Path = Field(description='Short name (`dirname.name`)')
     data_in: ImasBaseModel
     data_out: ImasBaseModel
-    operations: List[Union[IDSOperation, JettoOperation,
-                           List[Union[IDSOperation, JettoOperation]]]]
+    operations: list[Union[IDSOperation, JettoOperation,
+                           list[Union[IDSOperation, JettoOperation]]]]
 
     @root_validator()
     def shortname_compat(cls, root):
@@ -27,7 +27,7 @@ class Run(BaseModel):
 
 
 class Runs(BaseModel):
-    __root__: List[Run] = []
+    __root__: list[Run] = []
 
     def __iter__(self):
         yield from self.__root__
